OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "Потребителската сесия неочаквано изтече",
    "Provided email-address is not valid" : "Предоставеният е-мейл адрес е невалиден",
    "%s has published the calendar »%s«" : "%s е публикувал календар »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Неочаквана грешка при изпращането на имейл. Моля, свържете се с вашия администратор.",
    "Successfully sent email to %1$s" : "Успешно изпратен имейл до %1$s",
    "Hello," : "Здравейте, ",
    "We wanted to inform you that %s has published the calendar »%s«." : "Информираме ви, че%s е публикувал календарът »%s«.",
    "Open »%s«" : "Отвори »%s«",
    "Cheers!" : "Поздрави!",
    "Upcoming events" : "Предстоящи събития",
    "No more events today" : " Няма повече събития за днес",
    "No upcoming events" : "Няма предстоящи събития",
    "More events" : "Повече събития",
    "Calendar" : "Календар",
    "New booking {booking}" : "Нова резервация {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) резервира срещата „{config_display_name}“ на {date_time}.",
    "Appointments" : "Срещи",
    "Schedule appointment \"%s\"" : "Насрочване на среща „%s“",
    "Schedule an appointment" : "Насрочване на среща",
    "Prepare for %s" : "Подгответе се за %s",
    "Follow up for %s" : "Последващо действие за %s",
    "Your appointment \"%s\" with %s needs confirmation" : "Вашата среща „%s“ с %s, се нуждае от потвърждение",
    "Dear %s, please confirm your booking" : "Уважаеми %s, моля, потвърдете резервацията си",
    "Confirm" : "Потвърдете",
    "Description:" : "Описание:",
    "This confirmation link expires in %s hours." : "Тази връзка за потвърждение изтича след %s часа.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Ако все пак желаете да отмените срещата, моля, свържете се с вашият организатор, като отговорите на този имейл или като посетите страницата на профила му.",
    "Your appointment \"%s\" with %s has been accepted" : "Вашата среща „%s“ с %s, беше приета",
    "Dear %s, your booking has been accepted." : "Уважаеми %s, резервацията ви е приета.",
    "Appointment for:" : "Среща в:",
    "Date:" : "Дата:",
    "You will receive a link with the confirmation email" : "Ще получите връзка с имейла за потвърждение",
    "Where:" : "Къде:",
    "Comment:" : "Коментар:",
    "You have a new appointment booking \"%s\" from %s" : "Имате нова резервация за среща „%s“ от %s",
    "Dear %s, %s (%s) booked an appointment with you." : "Уважаемият/та  %s, %s (%s) резервира среща с вас.",
    "Location:" : "Местоположение:",
    "A Calendar app for Nextcloud" : "Календар за Nextcloud",
    "Previous day" : "Вчера",
    "Previous week" : "Миналата седмица",
    "Previous month" : "Предишен месец",
    "Next day" : "Утре",
    "Next week" : "Следваща седмица",
    "Next year" : "Следващата година",
    "Next month" : "Следващия месец",
    "Event" : "Събитие",
    "Today" : "Днес",
    "Day" : "Ден",
    "Week" : "Седмица",
    "Month" : "Месец",
    "Year" : "Година",
    "List" : "Списък",
    "Appointment link was copied to clipboard" : "Връзката за среща е копирана в клипборда",
    "Appointment link could not be copied to clipboard" : "Връзката за среща не можа да бъде копирана в клипборда",
    "Preview" : "Визуализация",
    "Copy link" : "Копиране на връзката",
    "Edit" : "Редакция",
    "Delete" : "Изтриване",
    "Create new" : "Създай нов",
    "Disable calendar \"{calendar}\"" : "Деактивиране на календар „{calendar}“",
    "Disable untitled calendar" : "Деактивиране на неозаглавен календар",
    "Enable calendar \"{calendar}\"" : "Активиране на календар „{calendar}“",
    "Enable untitled calendar" : "Активиране на неозаглавен календар",
    "An error occurred, unable to change visibility of the calendar." : "Възникна грешка, невъзможност да се промени видимостта на календара.",
    "Untitled calendar" : "Нов календар",
    "Shared with you by" : "Споделено с вас от",
    "Edit and share calendar" : "Редактиране и споделяне на календар",
    "Edit calendar" : "Редактиране на календар",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Прекратяване на споделянето на календара след  {countdown} секунди","Прекратяване на споделянето на календара след {countdown} секунди"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["И","Изтриване на календара след {countdown} секундии"],
    "An error occurred, unable to create the calendar." : "Възникна грешка, невъзможност да се създаде календар.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Моля, въведете валидна връзка (започваща с http://, https://, webcal://, или webcals://)",
    "Calendars" : "Kалендари",
    "Add new" : "Добави нов",
    "New calendar" : "Нов календар",
    "Name for new calendar" : "Име за нов календар",
    "Creating calendar …" : "Създаване на календар",
    "New calendar with task list" : "Нов календар със списък със задачи",
    "New subscription from link (read-only)" : "Нов абонамент от връзка (само за четене)",
    "Creating subscription …" : "Създаване на абонамент …",
    "Calendar link copied to clipboard." : "Връзка за Календара е копирана в клипборда",
    "Calendar link could not be copied to clipboard." : "Връзката за Календара не може да се копира в клипборда",
    "Copy subscription link" : "Копиране на връзката за абониране",
    "Copying link …" : "Копиране на връзката …",
    "Copied link" : "Копирано!",
    "Could not copy link" : "Връзката не можа да се копира",
    "Export" : "Експорт /изнасям/",
    "Untitled item" : "Неозаглавен елемент",
    "Unknown calendar" : "Неизвестен календар",
    "Could not load deleted calendars and objects" : "Не можаха да се заредят изтритите календари и обекти",
    "Could not delete calendar or event" : "Не можа да се изтрие календар или събитие",
    "Could not restore calendar or event" : "Не можа да се възстанови календар или събитие",
    "Do you really want to empty the trash bin?" : "Наистина ли искате да изпразните кошчето за боклук?",
    "Empty trash bin" : "Изпразване на кошчето за боклук",
    "Trash bin" : "Кошче",
    "Loading deleted items." : "Зареждане на изтрити елементи.",
    "You do not have any deleted items." : "Нямате изтрити елементи.",
    "Name" : "Име",
    "Deleted" : "Изтрито",
    "Restore" : "Възстановяне",
    "Delete permanently" : "Изтрий завинаги",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Елементите в кошчето за боклук се изтриват след {numDays} дни","Елементите в кошчето се изтриват след {numDays} дни"],
    "Could not update calendar order." : " Невъзможност да се актуализира записът в календара",
    "Deck" : "Deck",
    "Hidden" : "Скрит",
    "An error occurred, unable to publish calendar." : "Възникна грешка, невъзможност да се публикува календар.",
    "An error occurred, unable to send email." : "Възникна грешка, невъзможност да се изпрати имейл",
    "Embed code copied to clipboard." : "Кодът за вграждане е копиран в клипборда",
    "Embed code could not be copied to clipboard." : "Кодът за вграждане не можа да се копира в клипборда",
    "Unpublishing calendar failed" : "Премахването на публикуването на календара беше неуспешно",
    "Share link" : "Връзка за споделяне",
    "Copy public link" : "Копирай публичната връзка",
    "Send link to calendar via email" : "Изпрати връзката по имейл",
    "Enter one address" : "Въведете един адрес",
    "Sending email …" : "Изпращане на имейл …",
    "Copy embedding code" : "Копиране на кода за вграждане",
    "Copying code …" : "Копиране на кода …",
    "Copied code" : "Кодът е копиран",
    "Could not copy code" : "Кодът не можа да се копира",
    "Delete share link" : "Изтрий споделената връзка",
    "Deleting share link …" : "Изтриване на връзката за споделяне  ...",
    "An error occurred while unsharing the calendar." : "Възникна грешка при прекратяване на споделянето на календар.",
    "An error occurred, unable to change the permission of the share." : "Възникна грешка, невъзможност да се промени разрешението за споделяне ",
    "can edit" : "може да редактира",
    "Unshare with {displayName}" : "Прекратява споделянето с {displayName}",
    "Share with users or groups" : "Сподели с потребители или групи",
    "No users or groups" : "Няма потребители или групи",
    "Calendar name …" : "Име на календар ...",
    "Share calendar" : "Споделяне на календар",
    "Unshare from me" : "Прекратяване на споделянето от мен",
    "Save" : "Запазване",
    "No title" : "Без заглавие",
    "View" : "Изглед",
    "Import calendars" : "Импортиране на календари",
    "Please select a calendar to import into …" : "Моля, изберете календар, в който да импортирате",
    "Filename" : "Име на файла",
    "Calendar to import into" : "Избран календар за внасяне в",
    "Cancel" : "Отказ",
    "_Import calendar_::_Import calendars_" : ["Импортиране на календар","Импортиране на календари"],
    "Select the default location for attachments" : "Избор на местоположение на прикачените файлове по подразбиране",
    "Invalid location selected" : "Избрано е невалидно местоположение",
    "Attachments folder successfully saved." : "Папката с прикачени файлове е записана успешно.",
    "Error on saving attachments folder." : "Грешка при запазване на папката с прикачени файлове.",
    "Default attachments location" : "Местоположение на прикачените файлове по подразбиране",
    "{filename} could not be parsed" : "{filename} не можа да бъде анализиран",
    "No valid files found, aborting import" : "Не са намерени валидни файлове, прекъсване на импортирането",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Успешно импортиране на %n събития","Успешно импортиране на %n събития"],
    "Import partially failed. Imported {accepted} out of {total}." : "Импортирането е частично неуспешно. Импортирани {accepted} от {total}.",
    "Automatic" : "Автоматично",
    "Automatic ({detected})" : "Автоматично (detected})",
    "New setting was not saved successfully." : " Неуспешно запазване на новата настройка.",
    "Timezone" : "Часови пояс",
    "Navigation" : "Навигация",
    "Previous period" : "Предишен период",
    "Next period" : "Следващ период",
    "Views" : "Изгледи",
    "Day view" : "Дневен изглед",
    "Week view" : "Седмичен изглед",
    "Month view" : "Месечен изглед",
    "List view" : "Списъчен изглед",
    "Actions" : "Действия",
    "Create event" : "Създай събитие",
    "Show shortcuts" : "Показване на преките пътища",
    "Editor" : "Редактор",
    "Close editor" : "Затваряне на редактора",
    "Save edited event" : "Запиши редактираното събитие",
    "Delete edited event" : "Изтриване на редактираното събитие",
    "Duplicate event" : "Дублирано събитие",
    "or" : "или",
    "Calendar settings" : "Настройки на календар",
    "No reminder" : "Без напомняне",
    "CalDAV link copied to clipboard." : "Копиране на CalDAV връзка в клипборда",
    "CalDAV link could not be copied to clipboard." : "CalDAV връзката не може да бъде копирана в клипборда",
    "General" : "Общи",
    "Personal availability settings" : "Настройки за лична достъпност",
    "Copy primary CalDAV address" : "Копиране на основния CalDAV адрес",
    "Copy iOS/macOS CalDAV address" : "Копиране iOS/macOS CalDAV адрес",
    "Enable birthday calendar" : "Активиране на календара за рожден ден",
    "Show tasks in calendar" : "Показване на задачите в календара",
    "Show weekends" : "Покажи събота и неделя",
    "Show week numbers" : "Показвай номерата на седмиците",
    "Editing" : "Редактиране",
    "Default reminder" : "Напомняне по подразбиране",
    "Keyboard shortcuts" : "Бързи клавиши",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} минути","{duration} минути"],
    "0 minutes" : "0 минути",
    "_{duration} hour_::_{duration} hours_" : ["{duration} часа","{duration} минути"],
    "_{duration} day_::_{duration} days_" : ["{duration} дни","{duration} дни"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} минути","{duration} седмици"],
    "_{duration} month_::_{duration} months_" : ["{duration} месеца","{duration} минути"],
    "_{duration} year_::_{duration} years_" : ["{duration} години","{duration} минути"],
    "To configure appointments, add your email address in personal settings." : "За конфигуриране на срещи, добавете своя имейл адрес в личните настройки.",
    "Public – shown on the profile page" : "Публичен – показва се на страницата на профила",
    "Private – only accessible via secret link" : "Частен – достъпен само чрез тайна връзка",
    "Update" : "Обновяване",
    "Appointment name" : "Име на срещата",
    "Location" : "Местоположение",
    "Create a Talk room" : "Създаване на стая за разговори в приложението Talk",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "За всяка резервирана среща ще бъде генерирана уникална връзка, която ще бъде изпратена чрез имейла за потвърждение",
    "Description" : "Описание",
    "Visibility" : "Видимост",
    "Duration" : "Продължителност",
    "Increments" : "Стъпки",
    "Additional calendars to check for conflicts" : "Допълнителни календари за проверка за конфликти",
    "Pick time ranges where appointments are allowed" : "Избор на периоди от време, в които срещите са разрешени",
    "to" : "до",
    "Delete slot" : "Изтриване на слот",
    "No times set" : "Няма зададени часове",
    "Add" : "Добавяне",
    "Monday" : "понеделник",
    "Tuesday" : "Вторник",
    "Wednesday" : "Сряда",
    "Thursday" : "Четвъртък",
    "Friday" : "Петък",
    "Saturday" : "Събота",
    "Sunday" : "Неделя",
    "Add time before and after the event" : "Добавяне на време преди и след събитието",
    "Before the event" : "Преди събитието",
    "After the event" : "След събитието",
    "Planning restrictions" : "Ограничения за планиране",
    "Minimum time before next available slot" : "Минимално време преди следващия наличен слот",
    "Max slots per day" : "Максимален брой слотове на ден",
    "Limit how far in the future appointments can be booked" : "Ограничение, колко далеч в бъдеще могат да бъдат резервирани срещи",
    "Please confirm your reservation" : "Моля, потвърдете вашата резервация",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Изпратихме ви имейл с подробности. Моля, потвърдете вашата среща, като използвате връзката в имейла. Можете да затворите тази страница сега.",
    "Your name" : "Вашето име",
    "Your email address" : "Вашият имейл адрес",
    "Please share anything that will help prepare for our meeting" : "Моля, споделете всичко, което ще помогне да се подготвим за нашата среща",
    "Could not book the appointment. Please try again later or contact the organizer." : "Срещата не можа да резервира. Моля, опитайте отново по-късно или се свържете с организатора.",
    "Select conversation" : "Избор на разговор",
    "on" : "на",
    "at" : "в",
    "before at" : "преди в",
    "Notification" : "Известие",
    "Email" : "Имейл",
    "Audio notification" : "Звуково известие",
    "Other notification" : "Друго известие",
    "Relative to event" : "Относно събитието",
    "On date" : "На дата",
    "Edit time" : "Редакирай времето",
    "Save time" : "Запазване на времето",
    "Remove reminder" : "Премахни напомнянето",
    "Add reminder" : "Добавяне на напомняне",
    "seconds" : "секунди",
    "minutes" : "минути",
    "hours" : "часове",
    "days" : "дни",
    "weeks" : "седмици",
    "Choose a file to add as attachment" : "Избери файл за прикачване",
    "Choose a file to share as a link" : "Изберете файл, който да споделите като връзка",
    "Attachment {name} already exist!" : " Прикаченият файл {name} вече съществува!",
    "No attachments" : "Няма прикачени файлове",
    "Add from Files" : "Добавяне от файлове",
    "Upload from device" : "Качване от устройство",
    "Delete file" : "Изтриване на файл",
    "Confirmation" : "Потвърждение",
    "_{count} attachment_::_{count} attachments_" : ["{count} прикачени файлове","{count} прикачени файлове"],
    "Suggested" : "Препоръчан",
    "Available" : "Наличен.",
    "Invitation accepted" : "Поканата е приета",
    "Accepted {organizerName}'s invitation" : "Поканата на {organizerName} е приета",
    "Participation marked as tentative" : "Участието е отбелязано като условно",
    "Invitation is delegated" : "Поканата е делегирана",
    "Not available" : "Не е наличен",
    "Invitation declined" : "Поканата е отхвърлена",
    "Declined {organizerName}'s invitation" : "Поканата на {organizerName} е отхвърлена",
    "Checking availability" : "Проверка на наличността",
    "Has not responded to {organizerName}'s invitation yet" : "Все още няма отговор на поканата на {organizerName}",
    "{organizer} (organizer)" : "{organizer} (organizer)",
    "Availability of attendees, resources and rooms" : "Наличие на присъстващи, ресурси и стаи",
    "Legend" : "Легенда",
    "Out of office" : "Извън офиса",
    "Attendees:" : "Участници:",
    "Done" : "Завършено",
    "Room name" : "Име на стаята",
    "Free" : " Свободни",
    "Busy (tentative)" : "Зает (временно)",
    "Busy" : "Зает",
    "Unknown" : "Непознат",
    "The invitation has been accepted successfully." : "Поканата е приета успешно.",
    "Failed to accept the invitation." : "Неуспешно приемане на поканата.",
    "The invitation has been declined successfully." : "Поканата е отхвърлена успешно.",
    "Failed to decline the invitation." : "Неуспешно отхвърляне на поканата.",
    "Your participation has been marked as tentative." : "Участието ви е отбелязано като условно.",
    "Failed to set the participation status to tentative." : "Неуспешно задаване на състоянието за участие на условно.",
    "Accept" : "Приемам",
    "Decline" : "Отхвърляне",
    "Tentative" : "Несигурно",
    "No attendees yet" : "Все още няма участващи",
    "Successfully appended link to talk room to description." : "Успешно добавена връзка към стаята за разговори от описанието.",
    "Error creating Talk room" : "Грешка при създаването на Стая за разговори",
    "Attendees" : "Участници",
    "Remove group" : "Премахване на групата",
    "Remove attendee" : "Премахване на участник",
    "Chairperson" : "Председател",
    "Required participant" : "Необходим участник",
    "Optional participant" : " Участник по желание",
    "Non-participant" : "Неучастник",
    "Search for emails, users, contacts, contact groups or teams" : "Търси е-мейли, потребители, контакти, групи контакти или екипи.",
    "No match found" : "Няма намерено съвпадение",
    "(organizer)" : "(организатор)",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "За да изпращате покани и да обработвате отговори, [отваряне на връзка] добавете вашия имейл адрес в личните настройки [затваряне на връзка].",
    "Remove color" : "Премахване на цвят",
    "Event title" : "Заглавие на събитие",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Не може да се променя целодневната настройка за събития, които са част от набор за повторение.",
    "From" : "От",
    "To" : "До",
    "Repeat" : "Да се повтаря",
    "_time_::_times_" : ["пъти","пъти"],
    "never" : "никога",
    "on date" : "на дата",
    "after" : "след",
    "End repeat" : "Край на повторението",
    "Select to end repeat" : "Изберете, за да прекратите повторението",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Това събитие е изключено за повторение на набор от повторения. Не можете да добавите правило за повторение към него.",
    "first" : "първи",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Промените в правилото за повторение ще се прилагат само за това и за всички бъдещи събития.",
    "Repeat every" : "Повтаряй всеки",
    "By day of the month" : "От ден на месеца",
    "On the" : "На",
    "_day_::_days_" : ["ден","дни"],
    "_week_::_weeks_" : ["седмица","седмици"],
    "_month_::_months_" : ["месец","месеци"],
    "_year_::_years_" : ["година","години"],
    "weekday" : "делничен ден",
    "weekend day" : "Почивен ден",
    "Does not repeat" : "Не се повтаря",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Дефиницията за повторение на това събитие не се поддържа изцяло от Nextcloud. Ако се редактират опциите за повторение, някои повторения могат да бъдат загубени.",
    "No rooms or resources yet" : "Все още няма стаи или ресурси",
    "Resources" : "Ресурси",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} места","{seatingCapacity} места"],
    "Add resource" : "Добавяне на ресурс",
    "Has a projector" : "Има проектор",
    "Has a whiteboard" : "Има табло",
    "Wheelchair accessible" : "Достъпно за инвалидна количка",
    "Remove resource" : "Премахване на ресурс",
    "Search for resources or rooms" : "Търсене на ресурси или стаи",
    "available" : "наличен",
    "unavailable" : "не е наличен",
    "Projector" : "Проектор",
    "Whiteboard" : "Табло",
    "Room type" : "Тип стая",
    "Any" : "Всяка",
    "Minimum seating capacity" : "Минимален капацитет за сядане",
    "Update this and all future" : "Актуализиране на това и на всички бъдещи",
    "Update this occurrence" : "Актуализиране на това събитие",
    "Public calendar does not exist" : "Публичният календар не съществува",
    "Maybe the share was deleted or has expired?" : "Може би споделянето е изтрито или е изтекло?",
    "Yes" : "Да",
    "No" : "Не",
    "Maybe" : "Може би",
    "Create" : "Създаване",
    "from {formattedDate}" : "от {formattedDate}",
    "to {formattedDate}" : "до {formattedDate}",
    "on {formattedDate}" : "на {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "от {formattedDate} в {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "до {formattedDate} в{formattedTime}",
    "on {formattedDate} at {formattedTime}" : "на {formattedDate} в {formattedTime}",
    "{formattedDate} at {formattedTime}" : " {formattedDate} в {formattedTime}",
    "Please enter a valid date" : "Моля да въведете валидна дата",
    "Please enter a valid date and time" : "Моля да въведете валидна дата и час",
    "Please select a time zone:" : "Моля, изберете часова зона:",
    "Pick a time" : "Изберете час",
    "Pick a date" : "Изберете дата",
    "Type to search time zone" : "Въведете, за търсене на часова зона",
    "Global" : "Глобални",
    "Subscribed" : "Абониран",
    "Subscribe" : "Абониране",
    "Select slot" : "Избор на слот",
    "No slots available" : "Няма налични слотове",
    "The slot for your appointment has been confirmed" : "Слотът за вашата среща е потвърден",
    "Appointment Details:" : "Подробности за срещата:",
    "Time:" : "Час:",
    "Booked for:" : "Резервирано за:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Благодарим ви. Вашата резервация от {startDate} до {endDate} е потвърдена.",
    "Book another appointment:" : "Резервиране на друга среща:",
    "See all available slots" : "Вижте всички налични слотове",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Слотът за вашата среща от {startDate} до {endDate} вече не е наличен.",
    "Please book a different slot:" : "Моля, резервирайте друг слот:",
    "Book an appointment with {name}" : "Резервиране на среща с {name}",
    "No public appointments found for {name}" : "Няма намерени публични срещи за {name}",
    "Personal" : "Лични",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Автоматичното откриване на часовата зона, определи часовата ви зона като UTC.\nТова най-вероятно е резултат от мерките за сигурност на вашия уеб браузър.\nМоля, задайте часовата си зона ръчно в настройките за календар.",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Конфигурираната ви часова зона ({timezoneId}) не е намерена. Връщане към UTC.\nМоля, променете часовата си зона в настройките и докладвайте за този проблем.",
    "Edit event" : "Редакция на събитието",
    "Event does not exist" : "Събитието не съществува",
    "Duplicate" : "Дубликат",
    "Delete this occurrence" : "Изтриване на това събитие",
    "Delete this and all future" : "Изтриване на това и на всички бъдещи ",
    "All day" : "Цял ден",
    "Managing shared access" : "Управление на споделения достъп",
    "Deny access" : "Отказване на достъп",
    "Invite" : "Покани",
    "_User requires access to your file_::_Users require access to your file_" : ["Потребителите трябва да имат достъп до вашия файл","Потребителите трябва да имат достъп до вашия файл"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Прикачени файлове, изискващи споделен достъп","Прикачени файлове, изискващи споделен достъп"],
    "Untitled event" : "Събитие без заглавие",
    "Close" : "Затвори",
    "Selected" : "Избранo",
    "Title" : "Заглавие",
    "30 min" : "30 мин",
    "Participants" : "Участници",
    "Submit" : "Изпращане",
    "Subscribe to {name}" : "Абониране за {name}",
    "Export {name}" : "Експортиране /изнасям/ на {name}",
    "Anniversary" : "Годишнина",
    "Appointment" : "Среща",
    "Business" : "Бизнес",
    "Education" : "Обучение",
    "Holiday" : "Празник",
    "Meeting" : "Среща",
    "Miscellaneous" : "Разни",
    "Non-working hours" : "Неработно време",
    "Not in office" : "Не е в офиса",
    "Phone call" : "Телефонен разговор",
    "Sick day" : "Болничен ден",
    "Special occasion" : "Специален повод",
    "Travel" : "Пътуване",
    "Vacation" : "Отпуска",
    "Midnight on the day the event starts" : "Полунощ в деня, в който започва събитието",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%nдни преди събитието в {formattedHourMinute}","%nдни преди събитието в {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%nседмица преди събитието в {formattedHourMinute}","%nседмица преди събитието в {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "в деня на събитието в {formattedHourMinute}",
    "at the event's start" : "в началото на събитието",
    "at the event's end" : "в края на събитието",
    "{time} before the event starts" : "{time} преди начало на събитието",
    "{time} before the event ends" : "{time} преди край на събитието",
    "{time} after the event starts" : "{time} след началото на събитието",
    "{time} after the event ends" : "{time} след края на събитието",
    "on {time}" : "на {time}",
    "on {time} ({timezoneId})" : "на {time} ({timezoneId})",
    "Week {number} of {year}" : "Седмица {number} от {year}",
    "Daily" : "Всеки ден",
    "Weekly" : "Всяка седмица",
    "Monthly" : "Месечно",
    "Yearly" : "Годишно",
    "_Every %n day_::_Every %n days_" : ["Всеки %n ден","Всеки %n дни"],
    "_Every %n week_::_Every %n weeks_" : ["Всеки %nседмици","Всеки %n "],
    "_Every %n month_::_Every %n months_" : ["Всеки %nмесеци","Всеки %n месеци"],
    "_Every %n year_::_Every %n years_" : ["Всеки %n години","Всеки %n години"],
    "_on {weekday}_::_on {weekdays}_" : ["on {weekdays}","през {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["на дните {dayOfMonthList}","на дните {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "на {ordinalNumber} {byDaySet}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "през {monthNames} на {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "до {untilDate}",
    "_%n time_::_%n times_" : ["%n време","%n време"],
    "second" : "секунда",
    "third" : "трети",
    "fourth" : "четвърти",
    "fifth" : "пети",
    "second to last" : "предпоследен",
    "last" : "последен",
    "Untitled task" : "Задача без заглавие",
    "Please ask your administrator to enable the Tasks App." : "Моля, помолете вашия администратор да активира приложението за Задачи.",
    "W" : "W",
    "%n more" : "%n повече",
    "No events to display" : "Няма събития за показване",
    "_+%n more_::_+%n more_" : ["+","+%n повече"],
    "No events" : "Няма събития",
    "Create a new event or change the visible time-range" : "Създаване на ново събитие или промяна на видимия времеви диапазон",
    "It might have been deleted, or there was a typo in a link" : "Възможно е да е била изтрита или да е имало печатна грешка при въвеждането на връзката",
    "It might have been deleted, or there was a typo in the link" : "Възможно е да е била изтрита или да е имало печатна грешка при въвеждането на връзката",
    "Meeting room" : "Конферентна зала",
    "Lecture hall" : "Лекционна зала",
    "Seminar room" : "Зала за семинари",
    "Other" : "Други",
    "When shared show" : "Показване при споделяне",
    "When shared show full event" : "При споделяне, показвай цялото събитие",
    "When shared show only busy" : "При споделяне, показвай само статус \"зает\"",
    "When shared hide this event" : "При споделяне, скривай това събитие",
    "The visibility of this event in shared calendars." : "Видимостта на това събитие в споделени календари.",
    "Add a location" : "Добавяне на местоположение",
    "Status" : "Състояние",
    "Confirmed" : "Потвърдено",
    "Canceled" : "Отказано",
    "Confirmation about the overall status of the event." : "Потвърждение заобщото състояние на събитието.",
    "Show as" : "Показване като",
    "Take this event into account when calculating free-busy information." : " Това събитие да се вземе предвид при изчисляване на информация за заетостта.",
    "Categories" : "Категории",
    "Categories help you to structure and organize your events." : "Категориите ви помагат да структурирате и организирате вашите събития.",
    "Search or add categories" : "Търсене или прибавяне на категории",
    "Add this as a new category" : "Добави като нова категория",
    "Custom color" : "Персонализиране на цвят",
    "Special color of this event. Overrides the calendar-color." : "Специален цвят на това събитие. Сменя цвета на календара.",
    "Error while sharing file" : "Грешка при споделяне на файл",
    "Error while sharing file with user" : "Грешка при споделянето на файл с потребител",
    "Error creating a folder {folder}" : "Грешка при създаването на папка {folder}",
    "Attachment {fileName} already exists!" : " Прикаченият файл {fileName} вече съществува!",
    "An error occurred during getting file information" : "Възникна грешка при получаването на информация за файла",
    "An error occurred, unable to delete the calendar." : "Възникна грешка, невъзможност да се изтрие календара.",
    "Imported {filename}" : "Импортирано {filename}",
    "This is an event reminder." : "Това е напомняне за събитие.",
    "Appointment not found" : "Срещата не е намерена",
    "User not found" : "Потребителят не е намерен ",
    "Shortcut overview" : "Преглед на пряк път",
    "Enable simplified editor" : "Активиране на опростен редактор",
    "Limit the number of events displayed in the monthly view" : "Ограничаване на броя на събитията, показвани в месечния изглед",
    "Time increments" : "Времеви стъпки",
    "Show keyboard shortcuts" : "Показване на клавишни комбинации"
},
"nplurals=2; plural=(n != 1);");
